# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Python3 introduced in Fedora 13
%global with_python3 %([ "(" "%{__distinit}" == "fc" -a %{__distvers} -gt 12 ")" ] && echo 1 || echo 0)

# __python2 macro defined from Fedora 16 onwards
%{!?__python2: %global __python2 python2}

%{!?python2_sitelib: %global python2_sitelib %(python2 -c "from distutils.sysconfig import get_python_lib; print get_python_lib()" 2>/dev/null)}
%{!?python3_sitelib: %global python3_sitelib %(python3 -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())" 2>/dev/null)}
%global python2ver %(python2 -c "import sys; print sys.version[:3]" 2>/dev/null || echo 0.0)
%global python3ver %(python3 -c "import sys; print(sys.version[:3])" 2>/dev/null || echo 0.0)

Name:		python-passlib
Version:	1.6.5
Release:	4.%{__distinit}%{__distvers}
Summary:	Comprehensive password hashing framework supporting over 20 schemes
License:	BSD and Beerware and Copyright only
Group:		Development/Libraries
URL:		https://pythonhosted.org/passlib/
Source0:	https://pypi.python.org/packages/source/p/passlib/passlib-%{version}.tar.gz
Patch0:		passlib-1.6.1-check.patch
BuildArch:	noarch
BuildRoot:	%{_tmppath}/%{name}-%{version}-buildroot-%(id -nu)
# docs generation requires python-cloud-sptheme, which isn't packaged yet
# so we won't generate the docs yet
#BuildRequires: python-sphinx >= 1.0
#BuildRequires: python-cloud-sptheme

%description
Passlib is a password hashing library for Python 2 and 3, which provides
cross-platform implementations of over 20 password hashing algorithms,
as well as a framework for managing existing password hashes. It's
designed to be useful for a wide range of tasks, from verifying a hash
found in /etc/shadow, to providing full-strength password hashing for
multi-user application.

%package -n python2-passlib
Summary:	Comprehensive password hashing framework supporting over 20 schemes
Group:		Development/Libraries
Provides:	python-passlib = %{version}-%{release}
Obsoletes:	python-passlib < %{version}-%{release}
BuildRequires:	python2-devel >= 2.5
BuildRequires:	python-setuptools
# A suitable version is included in Fedora from F-16 onwards; on older releases,
# we can download one during %%check
%if 0%{?fedora} > 15 || 0%{?rhel} > 6
BuildRequires:	python-nose >= 1.1
%endif
# py-bcrypt requires python ≥ 2.6 and the test suite fails without it in 1.6.2
%if 0%{?fedora} > 10 || 0%{?rhel} > 5
BuildRequires:	py-bcrypt
%endif

%description -n python2-passlib
Passlib is a password hashing library for Python 2 and 3, which provides
cross-platform implementations of over 20 password hashing algorithms,
as well as a framework for managing existing password hashes. It's
designed to be useful for a wide range of tasks, from verifying a hash
found in /etc/shadow, to providing full-strength password hashing for
multi-user application.

%if 0%{?with_python3}
%package -n python3-passlib
Summary:	Comprehensive password hashing framework supporting over 20 schemes
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools
# A suitable version is included in Fedora from F-16 onwards; on older releases,
# we can download one during %%check
%if 0%{?fedora} > 15
BuildRequires:	python3-nose >= 1.1
%endif
BuildRequires:	python3-py-bcrypt

%description -n python3-passlib
Passlib is a password hashing library for Python 2 and 3, which provides
cross-platform implementations of over 20 password hashing algorithms,
as well as a framework for managing existing password hashes. It's
designed to be useful for a wide range of tasks, from verifying a hash
found in /etc/shadow, to providing full-strength password hashing for
multi-user application.
%endif

%prep
%setup -q -n passlib-%{version}

# Avoid exception on interpreter shutdown
# http://www.eby-sarna.com/pipermail/peak/2010-May/003355.html
%patch0

%build
%{__python2} setup.py build

%if 0%{?with_python3}
%{__python3} setup.py build
%endif

%install
rm -rf %{buildroot}
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}

%if 0%{?with_python3}
%{__python3} setup.py install -O1 --skip-build --root %{buildroot}
%endif

%check
# Complains about missing /dev/urandom on F-11 even though it's there
%if "%{?fedora}" != "11"
%{__python2} setup.py test
%endif

%if 0%{?with_python3}
%{__python3} setup.py test
%endif

%clean
rm -rf %{buildroot}

%files -n python2-passlib
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc CHANGES README
%{python2_sitelib}/passlib/
%{python2_sitelib}/passlib-%{version}-py%{python2ver}.egg-info/

%if 0%{?with_python3}
%files -n python3-passlib
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc CHANGES README
%{python3_sitelib}/passlib/
%{python3_sitelib}/passlib-%{version}-py%{python3ver}.egg-info/
%endif

%changelog
* Tue Oct 18 2016 Paul Howarth <paul@city-fan.org> - 1.6.5-4
- Generate python2 and python3 packages

* Wed Aug  5 2015 Paul Howarth <paul@city-fan.org> - 1.6.5-1
- Update to 1.6.5 (test suite fixes for python 2.5)
- Drop upstreamed fixes for python 2.5 support

* Thu Jul 30 2015 Paul Howarth <paul@city-fan.org> - 1.6.4-3
- Add workaround for bug in python 2.5.0 parser breaking
  from __future__ import with_statement, absolute_import

* Wed Jul 29 2015 Paul Howarth <paul@city-fan.org> - 1.6.4-2
- Use upstream fix for python 2.5 compatibility
  (https://bitbucket.org/ecollins/passlib/issues/58/)

* Mon Jul 27 2015 Paul Howarth <paul@city-fan.org> - 1.6.4-1
- Update to 1.6.4 (see CHANGES for details)
- Upstream moved from Google Code to Python Hosted
- Add fixes for a couple of test suite issues
- Use %%license where possible

* Wed Jan  1 2014 Paul Howarth <paul@city-fan.org> - 1.6.2-1
- Update to 1.6.2
  - Minor changes and compatibility fixes
    - Re-tuned the ~passlib.ifc.PasswordHash.default_rounds values for
      all of the hashes
    - Added the new bcrypt_sha256 hash, which wraps BCrypt using SHA256 in
      order to work around BCrypt's password size limitations (Issue 43)
    - passlib.hash.bcrypt: added support for the bcrypt library as one of the
      possible bcrypt backends that will be used if available (Issue 49)
    - passlib.ext.django: passlib's Django extension (and its related hashes
      and unittests) have been updated to handle some minor API changes in
      Django 1.5-1.6; they should now be compatible with Django 1.2 and up
      (Issue 50)
- BR: backend library py-bcrypt, required by test suite

* Sun Mar 17 2013 Paul Howarth <paul@city-fan.org> - 1.6.1-1
- Import from Fedora
- Update to 1.6.1

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Oct 17 2011 Matt Domsch <Matt_Domsch@dell.com> - 1.5.3-1
- Initial release for Fedora
